pub fn fingerprint(packs: &[RemotePack]) -> StringExpand description
Render a 16-char fingerprint of all loaded packs’ sha256s, in pack-load order. Lets e2e tests assert on a stable identity for the pack-source.
pub fn fingerprint(packs: &[RemotePack]) -> StringRender a 16-char fingerprint of all loaded packs’ sha256s, in pack-load order. Lets e2e tests assert on a stable identity for the pack-source.